@@ -5,7 +5,6 @@ import pandas as pd
 import os
 import xgboost as xgb
 
-from supervised.utils.config import storage_path
 from supervised.algorithms.algorithm import BaseAlgorithm
 from supervised.algorithms.registry import AlgorithmsRegistry
 from supervised.algorithms.registry import (
@@ -43,7 +42,7 @@ class XgbAlgorithm(BaseAlgorithm):
         self.max_iters = additional.get("max_steps", 500)
         self.learner_params = {
             "tree_method": "hist",
-            "booster": self.params.get("booster", "gbtree"),
+            "booster": "gbtree",
             "objective": self.params.get("objective"),
             "eval_metric": self.params.get("eval_metric"),
             "eta": self.params.get("eta", 0.01),
@@ -60,10 +59,6 @@ class XgbAlgorithm(BaseAlgorithm):
 
         logger.debug("XgbLearner __init__")
 
-    def update(self, update_params):
-        # Dont need to update boosting rounds, it is adding rounds incrementally
-        pass
-
     def fit(self, X, y):
         dtrain = xgb.DMatrix(X, label=y, missing=np.NaN)
         self.model = xgb.train(
@@ -99,14 +94,13 @@ class XgbAlgorithm(BaseAlgorithm):
         self.model.load_model(model_file_path)
 
     def get_params(self):
-        json_desc = {
+        return {
             "library_version": self.library_version,
             "algorithm_name": self.algorithm_name,
             "algorithm_short_name": self.algorithm_short_name,
             "uid": self.uid,
             "params": self.params,
         }
-        return json_desc
 
     def set_params(self, json_desc):
         self.library_version = json_desc.get("library_version", self.library_version)
@@ -117,16 +111,12 @@ class XgbAlgorithm(BaseAlgorithm):
         self.uid = json_desc.get("uid", self.uid)
         self.params = json_desc.get("params", self.params)
 
-    def file_extenstion(self):
+    def file_extension(self):
         return "xgboost"
 
-    def importance(self, column_names, normalize=True):
-        return None
-
 
 # For binary classification target should be 0, 1. There should be no NaNs in target.
 xgb_bin_class_params = {
-    "booster": ["gbtree", "gblinear"],
     "objective": ["binary:logistic"],
     "eval_metric": ["auc", "logloss"],
     "eta": [0.01, 0.025, 0.05, 0.075, 0.1, 0.15],
@@ -137,7 +127,6 @@ xgb_bin_class_params = {
 }
 
 xgb_regression_params = dict(xgb_bin_class_params)
-xgb_regression_params["booster"] = ["gbtree"]
 xgb_regression_params["objective"] = ["reg:squarederror"]
 xgb_regression_params["eval_metric"] = ["rmse", "rmsle", "mae"]
 xgb_regression_params["max_depth"] = [1, 2, 3, 4]
@@ -160,7 +149,6 @@ required_preprocessing = [
     "missing_values_inputation",
     "convert_categorical",
     "target_as_integer",
-    "target_scale",
 ]
 
 AlgorithmsRegistry.add(
@@ -179,6 +167,17 @@ AlgorithmsRegistry.add(
     additional,
 )
 
+regression_required_preprocessing = [
+    "missing_values_inputation",
+    "convert_categorical",
+    "target_scale",
+]
+
+
 AlgorithmsRegistry.add(
-    REGRESSION, XgbAlgorithm, xgb_regression_params, required_preprocessing, additional
+    REGRESSION,
+    XgbAlgorithm,
+    xgb_regression_params,
+    regression_required_preprocessing,
+    additional,
 )
